@@ -574,7 +574,7 @@ void Session::silenceTimerDone()
     }
 
     bool hasFocus = false;
-    for (TerminalDisplay *display : _views) {
+    foreach(TerminalDisplay *display, _views) {
         if (display->hasFocus()) {
             hasFocus = true;
             break;
@@ -634,7 +634,7 @@ void Session::activityStateSet(int state)
     } else if (state == NOTIFYACTIVITY) {
         // Don't notify if the terminal is active
         bool hasFocus = false;
-        for (TerminalDisplay *display : _views) {
+        foreach(TerminalDisplay *display, _views) {
             if (display->hasFocus()) {
                 hasFocus = true;
                 break;
@@ -1608,7 +1608,8 @@ void SessionGroup::forwardData(const QByteArray& data)
     }
 
     _inForwardData = true;
-    foreach(Session* other, _sessions.keys()) {
+    const QList<Session*> sessionsKeys = _sessions.keys();
+    foreach(Session* other, sessionsKeys) {
         if (!_sessions[other]) {
             other->emulation()->sendString(data);
         }
