@@ -84,9 +84,9 @@ using namespace Konsole;
 
 // TODO - Replace the icon choices below when suitable icons for silence and
 // activity are available
-Q_GLOBAL_STATIC_WITH_ARGS(QIcon, _activityIcon, (QIcon::fromTheme("dialog-information")));
-Q_GLOBAL_STATIC_WITH_ARGS(QIcon, _silenceIcon, (QIcon::fromTheme("dialog-information")));
-Q_GLOBAL_STATIC_WITH_ARGS(QIcon, _broadcastIcon, (QIcon::fromTheme("emblem-important")));
+Q_GLOBAL_STATIC_WITH_ARGS(QIcon, _activityIcon, (QIcon::fromTheme("dialog-information")))
+Q_GLOBAL_STATIC_WITH_ARGS(QIcon, _silenceIcon, (QIcon::fromTheme("dialog-information")))
+Q_GLOBAL_STATIC_WITH_ARGS(QIcon, _broadcastIcon, (QIcon::fromTheme("emblem-important")))
 
 QSet<SessionController*> SessionController::_allControllers;
 int SessionController::_lastControllerId;
@@ -531,7 +531,7 @@ void SessionController::setupCommonActions()
         action->setText(i18n("&Close Tab"));
 
     action->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_W);
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_W);
 
     // Open Browser
     action = collection->addAction("open-browser", this, SLOT(openBrowser()));
@@ -540,19 +540,34 @@ void SessionController::setupCommonActions()
 
     // Copy and Paste
     action = KStandardAction::copy(this, SLOT(copy()), collection);
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_C);
+#ifdef Q_OS_OSX
+    // Don't use the Konsole::ACCEL const here, we really want the Command key (Qt::META)
+    // TODO: check what happens if we leave it to Qt to assign the default?
+    collection->setDefaultShortcut(action, Qt::META + Qt::Key_C);
+#else
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_C);
+#endif
     // disabled at first, since nothing has been selected now
     action->setEnabled(false);
 
     action = KStandardAction::paste(this, SLOT(paste()), collection);
     QList<QKeySequence> pasteShortcut;
-    pasteShortcut.append(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_V));
+#ifdef Q_OS_OSX
+    pasteShortcut.append(QKeySequence(Qt::META + Qt::Key_V));
+    // No Insert key on Mac keyboards
+#else
+    pasteShortcut.append(QKeySequence(Konsole::ACCEL + Qt::SHIFT + Qt::Key_V));
     pasteShortcut.append(QKeySequence(Qt::SHIFT + Qt::Key_Insert));
+#endif
     collection->setDefaultShortcuts(action, pasteShortcut);
 
     action = collection->addAction("paste-selection", this, SLOT(pasteFromX11Selection()));
     action->setText(i18n("Paste Selection"));
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_Insert);
+#ifdef Q_OS_OSX
+    collection->setDefaultShortcut(action, Qt::META + Qt::SHIFT + Qt::Key_V);
+#else
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_Insert);
+#endif
 
     _webSearchMenu = new KActionMenu(i18n("Web Search"), this);
     _webSearchMenu->setIcon(QIcon::fromTheme(QStringLiteral("preferences-web-browser-shortcuts")));
@@ -569,10 +584,13 @@ void SessionController::setupCommonActions()
 
     action = KStandardAction::saveAs(this, SLOT(saveHistory()), collection);
     action->setText(i18n("Save Output &As..."));
+#ifdef Q_OS_OSX
+    action->setShortcut(QKeySequence(Qt::META + Qt::Key_S));
+#endif
 
     action = KStandardAction::print(this, SLOT(print_screen()), collection);
     action->setText(i18n("&Print Screen..."));
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_P);
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_P);
 
     action = collection->addAction("adjust-history", this, SLOT(showHistoryOptions()));
     action->setText(i18n("Adjust Scrollback..."));
@@ -585,7 +603,7 @@ void SessionController::setupCommonActions()
     action = collection->addAction("clear-history-and-reset", this, SLOT(clearHistoryAndReset()));
     action->setText(i18n("Clear Scrollback and Reset"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-history")));
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_K);
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_K);
 
     // Profile Options
     action = collection->addAction("edit-current-profile", this, SLOT(editCurrentProfile()));
@@ -626,7 +644,7 @@ void SessionController::setupExtraActions()
     action = collection->addAction("rename-session", this, SLOT(renameSession()));
     action->setText(i18n("&Rename Tab..."));
     action->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::ALT + Qt::Key_S);
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::ALT + Qt::Key_S);
 
     // Copy input to ==> all tabs
     KToggleAction* copyInputToAllTabsAction = collection->add<KToggleAction>("copy-input-to-all-tabs");
@@ -638,13 +656,13 @@ void SessionController::setupExtraActions()
     // Copy input to ==> selected tabs
     KToggleAction* copyInputToSelectedTabsAction = collection->add<KToggleAction>("copy-input-to-selected-tabs");
     copyInputToSelectedTabsAction->setText(i18n("&Select Tabs..."));
-    collection->setDefaultShortcut(copyInputToSelectedTabsAction, Qt::CTRL + Qt::SHIFT + Qt::Key_Period);
+    collection->setDefaultShortcut(copyInputToSelectedTabsAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_Period);
     copyInputToSelectedTabsAction->setData(CopyInputToSelectedTabsMode);
 
     // Copy input to ==> none
     KToggleAction* copyInputToNoneAction = collection->add<KToggleAction>("copy-input-to-none");
     copyInputToNoneAction->setText(i18nc("@action:inmenu Do not select any tabs", "&None"));
-    collection->setDefaultShortcut(copyInputToNoneAction, Qt::CTRL + Qt::SHIFT + Qt::Key_Slash);
+    collection->setDefaultShortcut(copyInputToNoneAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_Slash);
     copyInputToNoneAction->setData(CopyInputToNoneMode);
     copyInputToNoneAction->setChecked(true); // the default state
 
@@ -660,16 +678,16 @@ void SessionController::setupExtraActions()
     action = collection->addAction("zmodem-upload", this, SLOT(zmodemUpload()));
     action->setText(i18n("&ZModem Upload..."));
     action->setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::ALT + Qt::Key_U);
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::ALT + Qt::Key_U);
 
     // Monitor
     toggleAction = new KToggleAction(i18n("Monitor for &Activity"), this);
-    collection->setDefaultShortcut(toggleAction, Qt::CTRL + Qt::SHIFT + Qt::Key_A);
+    collection->setDefaultShortcut(toggleAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_A);
     action = collection->addAction("monitor-activity", toggleAction);
     connect(action, &QAction::toggled, this, &Konsole::SessionController::monitorActivity);
 
     toggleAction = new KToggleAction(i18n("Monitor for &Silence"), this);
-    collection->setDefaultShortcut(toggleAction, Qt::CTRL + Qt::SHIFT + Qt::Key_I);
+    collection->setDefaultShortcut(toggleAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_I);
     action = collection->addAction("monitor-silence", toggleAction);
     connect(action, &QAction::toggled, this, &Konsole::SessionController::monitorSilence);
 
@@ -678,14 +696,14 @@ void SessionController::setupExtraActions()
     action->setText(i18n("Enlarge Font"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("format-font-size-more")));
     QList<QKeySequence> enlargeFontShortcut;
-    enlargeFontShortcut.append(QKeySequence(Qt::CTRL + Qt::Key_Plus));
-    enlargeFontShortcut.append(QKeySequence(Qt::CTRL + Qt::Key_Equal));
+    enlargeFontShortcut.append(QKeySequence(Konsole::ACCEL + Qt::Key_Plus));
+    enlargeFontShortcut.append(QKeySequence(Konsole::ACCEL + Qt::Key_Equal));
     collection->setDefaultShortcuts(action, enlargeFontShortcut);
 
     action = collection->addAction("shrink-font", this, SLOT(decreaseFontSize()));
     action->setText(i18n("Shrink Font"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("format-font-size-less")));
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::Key_Minus);
+    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::Key_Minus);
 
 
     // Send signal
@@ -733,9 +751,15 @@ void SessionController::setupExtraActions()
     action->setData(SIGUSR2);
     sendSignalActions->addAction(action);
 
-    collection->setDefaultShortcut(_findAction, Qt::CTRL + Qt::SHIFT + Qt::Key_F);
+#ifdef Q_OS_OSX
+    collection->setDefaultShortcut(_findAction, Qt::META + Qt::Key_F);
+    collection->setDefaultShortcut(_findNextAction, Qt::META + Qt::Key_G);
+    collection->setDefaultShortcut(_findPreviousAction, Qt::META + Qt::SHIFT + Qt::Key_G);
+#else
+    collection->setDefaultShortcut(_findAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_F);
     collection->setDefaultShortcut(_findNextAction, Qt::Key_F3);
     collection->setDefaultShortcut(_findPreviousAction, Qt::SHIFT + Qt::Key_F3);
+#endif
 }
 
 void SessionController::switchProfile(Profile::Ptr profile)
@@ -772,7 +796,8 @@ EditProfileDialog* SessionController::profileDialogPointer()
 void SessionController::editCurrentProfile()
 {
     // Searching for Edit profile dialog opened with the same profile
-    foreach (SessionController* session, _allControllers.values()) {
+    const QList<SessionController*> allSessionsControllers = _allControllers.values();
+    foreach (SessionController* session, allSessionsControllers) {
         if (session->profileDialogPointer()
                 && session->profileDialogPointer()->isVisible()
                 && session->profileDialogPointer()->lookupProfile() == SessionManager::instance()->sessionProfile(_session)) {
@@ -1737,7 +1762,7 @@ void SaveHistoryTask::execute()
         // this is set to -1 to indicate the job has just been started
 
         if (((dialog->selectedNameFilter()).contains("html", Qt::CaseInsensitive)) ||
-           ((dialog->selectedFiles()).at(0).endsWith("html", Qt::CaseInsensitive))) {
+           ((dialog->selectedFiles()).at(0).endsWith(QLatin1String("html"), Qt::CaseInsensitive))) {
             jobInfo.decoder = new HTMLDecoder();
         } else {
             jobInfo.decoder = new PlainTextDecoder();
