@@ -69,11 +69,18 @@ void ShellCommandTest::testExpandEnvironmentVariable()
     const QString expected = text.replace('$' + env, value);
     QCOMPARE(result, expected);
 
-    text = QLatin1String("PATH=$PATH:\\$ESCAPED:~/bin");
+    text = QStringLiteral("PATH=$PATH:\\$ESCAPED:~/bin");
     qputenv(env.toLocal8Bit().constData(), value.toLocal8Bit());
     const QString result2 = ShellCommand::expand(text);
     const QString expected2 = text.replace('$' + env, value);
     QCOMPARE(result2, expected2);
+
+    text = QStringLiteral("$ABC \"$ABC\" '$ABC'");
+    qputenv("ABC", "123");
+    const QString result3 = ShellCommand::expand(text);
+    const QString expected3 = QStringLiteral("123 \"123\" '$ABC'");
+    QEXPECT_FAIL("", "Bug 361835", Continue);
+    QCOMPARE(result3, expected3);
 }
 
 void ShellCommandTest::testValidEnvCharacter()
