@@ -98,7 +98,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char* argv[])
                      QStringLiteral(KONSOLE_VERSION),
                      i18nc("@title", "Terminal emulator"),
                      KAboutLicense::GPL_V2,
-                     i18n("(c) 1997-2015, The Konsole Developers"),
+                     i18n("(c) 1997-2017, The Konsole Developers"),
                      QStringLiteral(),
                      QStringLiteral("https://konsole.kde.org/"));
     fillAboutData(about);
@@ -112,13 +112,17 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char* argv[])
     parser->addHelpOption();
     parser->addVersionOption();
     about.setupCommandLine(parser.data());
+
+    QStringList args = QStringList(app->arguments());
+    QStringList customCommand = Application::getCustomCommand(args);
+
     Application::populateCommandLineParser(parser.data());
 
-    parser->process(*app);
+    parser->process(args);
     about.processCommandLine(parser.data());
 
-    // Enable user to force multiple instances
-    if (!Konsole::KonsoleSettings::useSingleInstance()) {
+    // Enable user to force multiple instances, unless a new tab is requested
+    if (!Konsole::KonsoleSettings::useSingleInstance() && !parser->isSet(QStringLiteral("new-tab"))) {
         startupOption = KDBusService::Multiple;
     }
 
@@ -158,7 +162,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char* argv[])
 
     // If we reach this location, there was no existing copy of Konsole
     // running, so create a new instance.
-    Application konsoleApp(parser);
+    Application konsoleApp(parser, customCommand);
 
     // The activateRequested() signal is emitted when a second instance
     // of Konsole is started.
